nothing

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package nothing doesn't do much, except for providing the “Nothing” type-alias for “struct{}”, in the same vein as “any” as conveniently expressive shorthand for “interface{}”.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Nothing

type Nothing = struct{}

Nothing is an expressive alias for “struct {}”. Not really necessary but makes code more readable for those who prefer this kind of better readability. Especially nice when dot-importing "nothing".

Jump to